@@ -5,10 +5,10 @@ import numpy as np
 import numpy.typing as npt
 import tensorflow as tf  # type: ignore
 
-from code_loader.contract.visualizer_classes import LeapImage, LeapText, LeapGraph, LeapHorizontalBar, \
-    LeapTextMask, LeapImageMask, LeapImageWithBBox
 from code_loader.contract.enums import DataStateType, DatasetMetadataType, \
     DataStateEnum, LeapDataType, Metric, ConfusionMatrixValue
+from code_loader.contract.visualizer_classes import LeapImage, LeapText, LeapGraph, LeapHorizontalBar, \
+    LeapTextMask, LeapImageMask, LeapImageWithBBox
 
 
 @dataclass
@@ -65,6 +65,10 @@ class ConfusionMatrixElement:
 
 ConfusionMatrixCallableInterface = Callable[[tf.Tensor, tf.Tensor], List[List[ConfusionMatrixElement]]]
 
+CustomCallableInterfaceMultiArgs = Callable[..., tf.Tensor]
+ConfusionMatrixCallableInterfaceMultiArgs = Callable[..., List[List[ConfusionMatrixElement]]]
+MetricCallableReturnType = Union[tf.Tensor, List[List[ConfusionMatrixElement]]]
+
 
 @dataclass
 class CustomLossHandler:
@@ -72,6 +76,13 @@ class CustomLossHandler:
     function: CustomCallableInterface
 
 
+@dataclass
+class MetricHandler:
+    name: str
+    function: Union[CustomCallableInterfaceMultiArgs, ConfusionMatrixCallableInterfaceMultiArgs]
+    arg_names: List[str]
+
+
 @dataclass
 class VisualizerHandler:
     name: str
@@ -108,7 +119,7 @@ class MetadataHandler:
 class PredictionTypeHandler:
     name: str
     labels: List[str]
-    metrics: List[Metric]
+    metrics: Optional[List[Metric]] = None
     custom_metrics: Optional[List[Union[CustomCallableInterface, ConfusionMatrixCallableInterface]]] = None
 
 
@@ -130,6 +141,7 @@ class DatasetIntegrationSetup:
     metadata: List[MetadataHandler] = field(default_factory=list)
     prediction_types: List[PredictionTypeHandler] = field(default_factory=list)
     custom_loss_handlers: List[CustomLossHandler] = field(default_factory=list)
+    metrics: List[MetricHandler] = field(default_factory=list)
     custom_layers: Dict[str, CustomLayerHandler] = field(default_factory=dict)
 
 
